using System.Security.Cryptography;
using System.Text;
using Jose;

namespace FitConnect.Encryption;

public static class EncryptionSettings {
    public static readonly int CertificateChainLength = 3;
    public static readonly string SigningAlgorithm = "PS512";
    public static readonly string EncryptionAlgorithm = "RSA-OAEP-256";
    public static readonly string JwtHeaderType = "secevent+jwt";
    public static readonly string ShaType = "sha512";
    public static readonly IEnumerable<string> ValidTokenAlgorithms = new[] { "PS512" };
    public static readonly int MinKeySize = 4096;
    public static readonly string KeyOpsWrapKey = "wrapKey";
    public static readonly string KeyOpsVerify = "verify";

    public const JweEncryption Encryption = JweEncryption.A256GCM;
    public const JweCompression Compression = JweCompression.DEF;
    public const JweAlgorithm Algorithm = JweAlgorithm.RSA_OAEP_256;
    public const SerializationMode SerializationMode = Jose.SerializationMode.Compact;

    public static byte[] CalculateCallbackHmac(string callbackSecret, long timestamp, string body) {
        return new HMACSHA512(Encoding.UTF8.GetBytes(callbackSecret))
            .ComputeHash(Encoding.UTF8.GetBytes($"{timestamp}.{body}"));
    }

    public static byte[] CalculateHash(byte[] plain) => SHA512.Create().ComputeHash(plain);
}
